/*
 * Hosts DB Manager

     Copyright (c) 2003, Gumbynet & Damien Gardner Jnr
     All rights reserved.

     Redistribution and use in source and binary forms, with or without modification,
     are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice, this list
         of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice, this list
         of conditions and the following disclaimer in the documentation and/or other
         materials provided with the distribution.
     * Neither the name of GumbyNet nor the names of its contributors may be used to
         endorse or promote products derived from this software without specific prior written permission.

     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS
     OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
     AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
     OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
     CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
     SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
     THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
     OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.gumbynet.carnivore.managers;

import org.gumbynet.carnivore.objects.Host;
import org.gumbynet.carnivore.objects.Service;

import java.util.Vector;
import java.util.Properties;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;

public class HostManager {
    Properties settings;
    Connection con;

    public HostManager(Properties settings) {
        this.settings = settings;
        // Register the DB Driver
        try {
            Class driver = Class.forName(settings.getProperty("dbDriver"));
        } catch (Exception e) {System.out.println("Couldn't register DB Driver!"); }

        try {
            con = DriverManager.getConnection(settings.getProperty("dbServer"), settings.getProperty("dbUser"), settings.getProperty("dbPassword"));
        } catch (Exception e) {
            System.out.println("Can't get DB Connection to "+settings.getProperty("dbDriver"));
            e.printStackTrace();
        }

    }

    public Vector retrieveHostList() {

        PreparedStatement ps = null;
        ResultSet rs = null;
        Vector vcrReturnSet = new Vector();

        try {
            ps = con.prepareStatement("select * from host where enabled='Y' order by host_id");
            rs = ps.executeQuery();
            while (rs.next()) {
                Host hstHost = new Host(rs.getInt("host_id"), rs.getString("host_name"), rs.getString("host_ip"));
                getServicesforHost(hstHost);
                vcrReturnSet.add(hstHost);
            }
            rs.close();
            ps.close();

        } catch (Exception e) {
            if (rs != null) { try { rs.close(); } catch (Exception e2) {} }
            if (ps != null) { try { ps.close(); } catch (Exception e2) {} }
        }


        return vcrReturnSet;

    }

    public void getServicesforHost(Host hstHost) {
        PreparedStatement ps = null;
        ResultSet rs = null;
        Vector vcrReturnSet = new Vector();

        try {
            ps = con.prepareStatement("select service.service_id, service.service_code, service_class from service, host_services where host_services.service_id=service.service_id and host_services.host_id=? and host_services.enabled='Y' order by service.service_id");
            ps.setInt(1, hstHost.getId());
            rs = ps.executeQuery();
            while (rs.next()) {
                vcrReturnSet.add(new Service(rs.getInt("service_id"), rs.getString("service_code"), rs.getString("service_class")));
            }
            rs.close();
            ps.close();

        } catch (Exception e) {
            if (rs != null) { try { rs.close(); } catch (Exception e2) {} }
            if (ps != null) { try { ps.close(); } catch (Exception e2) {} }
        }

        hstHost.setServices(vcrReturnSet);
//        return hstHost;
    }
}
