/*
 * Carnivore Monitor controller Thread

     Copyright (c) 2003, Gumbynet & Damien Gardner Jnr
     All rights reserved.

     Redistribution and use in source and binary forms, with or without modification,
     are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice, this list
         of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice, this list
         of conditions and the following disclaimer in the documentation and/or other
         materials provided with the distribution.
     * Neither the name of GumbyNet nor the names of its contributors may be used to
         endorse or promote products derived from this software without specific prior written permission.

     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS
     OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
     AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
     OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
     CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
     SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
     THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
     OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 */
package org.gumbynet.carnivore.server;

import org.gumbynet.carnivore.utils.Logger;
import org.gumbynet.carnivore.managers.HostManager;
import org.gumbynet.carnivore.objects.Host;

import java.util.Properties;
import java.util.Vector;

public class MonitorThread extends Thread {

    private Properties settings;
    private Logger logLogger;
    private HostManager hmHostManager;
    private Vector vcrHostList = null;

    public MonitorThread (Properties settings, Logger logLogger) {
        this.settings = settings;
        this.logLogger = logLogger;
        this.hmHostManager = new HostManager(settings);


    }


    public void run() {
        logLogger.logIt(this.getClass(), "INFO", "Started");

        HostLogHandlerThread hlhtLog = new HostLogHandlerThread(this.settings, this.logLogger);
        hlhtLog.start();

        // Populate Host Vector List
        vcrHostList = hmHostManager.retrieveHostList();
        logLogger.logIt(this.getClass(), "INFO", "Loaded Host List - "+vcrHostList.size()+" hosts");
        Vector vcrThreadList = new Vector();

        while (true) {
            for (int i = 0; i < vcrHostList.size(); i++) {
                Host hstHost = (Host) vcrHostList.elementAt(i);
//                System.out.println("Host: "+hstHost.getName());
//                System.out.println("hstHost.getServices().size() = " + hstHost.getServices().size());
                if (hstHost.getServices().size() > 0) {
                    // Add it to monitoring..
                    HostThread ht = new HostThread(hstHost, hlhtLog, vcrThreadList);
                    vcrThreadList.add(ht);
                    ht.start();
                }
            }
          logLogger.logIt(this.getClass(), "NOISE", "Queued "+ vcrHostList.size()+" hosts for testing");


            try {
                sleep(300000);
            } catch (InterruptedException e) {
                e.printStackTrace();  //To change body of catch statement use Options | File Templates.
            }

        }

    }




}
