/*
 * Ping JNI Wrapper

     Copyright (c) 2003, Gumbynet & Damien Gardner Jnr
     All rights reserved.

     Redistribution and use in source and binary forms, with or without modification,
     are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice, this list
         of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice, this list
         of conditions and the following disclaimer in the documentation and/or other
         materials provided with the distribution.
     * Neither the name of GumbyNet nor the names of its contributors may be used to
         endorse or promote products derived from this software without specific prior written permission.

     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS
     OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
     AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
     OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
     CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
     SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
     THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
     OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.gumbynet.carnivore.utils;

import java.util.HashSet;
import java.math.BigInteger;

public class PingHandler {

    private native String icmp_sendrecv(String host, int sequence, String data, int timeout);


    static {
        System.loadLibrary("ping");
    }

    private int counter;
    private HashSet received;

    public PingHandler() {
        counter = 0;
        received = new HashSet();
    }

    public long send(String host, int timeout) {
        return send(host, "012345678901234567890123456789", timeout);
    }

    public long send(String host, int bytes, int timeout) {
        StringBuffer sb = new StringBuffer();

        for (int i = 0; i < bytes; i++) {
            sb.append(i % 9);
        }

        return send(host, sb.toString(), timeout);
    }

    public long send(String host, String data, int timeout) {
        if (data.length() > 64000) {
            System.err.println("Data item too long. 64,000 bytes max.");
            return -5;
        }

        data = System.currentTimeMillis() + " " + data;

        String res = icmp_sendrecv(host, counter, data, timeout);

      long endtime = System.currentTimeMillis();

      boolean duplicate = false;

      Integer I = new Integer(res.substring(0, res.indexOf(" ")));
      if (received.contains(I)) {
          duplicate = true;
      } else {
          received.add(I);
      }

      String data2 = res.substring((res.indexOf(" ") + 1));
      data2 = data2.substring(0, data2.indexOf(" "));
      BigInteger bi = new BigInteger(data2);
      long starttime = bi.longValue();



        counter++;

      return (endtime - starttime);
    }

}
